#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# @author: Giancarlo Panichi
#
# Created on 2018/06/15 
# 
import sys
import os
from command.storagehubcommandrootinfo import StorageHubCommandRootInfo 
from command.storagehubcommanditeminfo import StorageHubCommandItemInfo
from command.storagehubcommandrootchildren import StorageHubCommandRootChildren
from command.storagehubcommanditemchildren import StorageHubCommandItemChildren
from command.storagehubcommanditemdownload import StorageHubCommandItemDownload
from command.storagehubcommanditemupload import StorageHubCommandItemUpload
import issupport


class StorageHubFacility: 

    def __init__(self): 
        self.operation = sys.argv[1] 
        self.destinationFile = "outFile"
        self.globalVariablesFile = "globalvariables.csv"
        self.gcubeToken = None
        self.storageHubUrl = None
        
    def main(self):
        print(self)
        self.retrieveToken()
        issup = issupport.ISSupport()
        self.storageHubUrl = issup.discoverStorageHub(self.gcubeToken)
        self.executeOperation()
        
    def retrieveToken(self): 
        print("Retrieve gcubeToken")
        if not os.path.isfile(self.globalVariablesFile):
            print("File does not exist: " + self.globalVariablesFile)
            raise Exception("File does not exist: " + self.globalVariablesFile)  
        with open(self.globalVariablesFile) as fp:
            for line in fp:
                if line.find("gcube_token") != -1:
                    tk = line[14:]
                    self.gcubeToken = tk.replace('"', '').strip()
                    print("Found gcube_token")
                    break
        if self.gcubeToken == None:
            print('Error gcube_token not found!')
            raise Exception('Error gcube_token not found!')  
    
    def executeOperation(self):
        print("Execute Operation")
        if self.operation == 'RootInfo':
            opRootInfo=StorageHubCommandRootInfo(self.gcubeToken, self.storageHubUrl, self.destinationFile)
            opRootInfo.execute()
        elif self.operation == 'ItemInfo':
            opItemInfo=StorageHubCommandItemInfo(sys.argv[2], self.gcubeToken, self.storageHubUrl, self.destinationFile)
            opItemInfo.execute()
        elif self.operation == 'RootChildren':
            opRootChildren=StorageHubCommandRootChildren(self.gcubeToken, self.storageHubUrl, self.destinationFile)
            opRootChildren.execute()
        elif self.operation == 'ItemChildren':
            opItemChildren=StorageHubCommandItemChildren(sys.argv[2], self.gcubeToken, self.storageHubUrl, self.destinationFile)
            opItemChildren.execute()
        elif self.operation == 'Download':
            opDownload=StorageHubCommandItemDownload(sys.argv[2], self.gcubeToken, self.storageHubUrl, self.destinationFile)
            opDownload.execute()
        elif self.operation == 'Upload':
            opUpload=StorageHubCommandItemUpload(sys.argv[2], self.gcubeToken, self.storageHubUrl, sys.argv[3], sys.argv[4],  sys.argv[4], self.destinationFile)
            opUpload.execute()    
        else:        
            pass
        
            
        
        
        
    def __str__(self): 
        return 'StorageHubFacility[operation=' + str(self.operation) +  ']' 


def main():
    print('storagehub-facility-python')
    sh = StorageHubFacility()
    sh.main()

   
main()
